@@ -10,6 +10,12 @@ App::perluse - Use the specified perl in shell command
 
   $ cpanm App::perluse
 
+  $ perluse 5.18.1 perl -E 'say $^V'
+
+  $ perluse blead perldoc perldelta
+
+  $ perluse perl-5.18.1
+
   $ perluse
 
 =head1 DESCRIPTION
@@ -17,9 +23,8 @@ App::perluse - Use the specified perl in shell command
 See perluse(1) for available command line options.
 
 C<App::perluse> is not real module because perluse(1) command is just a POSIX
-shell script.
-
-It allows to install this script with cpan(1) or cpanm(1) command.
+shell script and it allows to install this script with cpan(1) or cpanm(1)
+command.
 
 =cut
 
@@ -29,12 +34,26 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 
 1;
 
 
+=head1 INSTALLATION
+
+=head2 With cpanm(1)
+
+  $ cpanm App::perluse
+
+=head2 Directly
+
+  $ lwp-request http://git.io/dXVJCg | sh
+
+or
+
+  $ curl -kL http://git.io/dXVJCg | sh
+
 =head1 SEE ALSO
 
 L<http://github.com/dex4er/perluse>, perluse(1).
